@@ -1,19 +1,13 @@
 package Bio::Phylo::Treedrawer::Swf;
 use strict;
+use base 'Bio::Phylo::Treedrawer::Abstract';
 use Bio::Phylo::Util::Exceptions 'throw';
 use Bio::Phylo::Util::CONSTANT 'looks_like_hash';
+use Bio::Phylo::Util::Dependency 'SWF::Builder';
 use Bio::Phylo::Util::Logger;
-use Bio::Phylo::Treedrawer::Abstract;
-use vars qw(@ISA $FONT);
-@ISA=qw(Bio::Phylo::Treedrawer::Abstract);
-
+our $FONT;
 my $logger = Bio::Phylo::Util::Logger->new;
-
-eval { require SWF::Builder };
-if ( $@ ) {
-    throw 'ExtensionError' => "Error loading the SWF::Builder extension: $@";
-}
-my $PI = '3.14159265358979323846';
+my $PI     = '3.14159265358979323846';
 my %colors;
 
 =head1 NAME
@@ -44,19 +38,16 @@ learn how to create tree drawings.
 
 sub _new {
     my $class = shift;
-    my %opt = looks_like_hash @_;
-    my $self = $class->SUPER::_new(
-        %opt, '-api' => SWF::Builder->new(
+    my %opt   = looks_like_hash @_;
+    my $self  = $class->SUPER::_new(
+        %opt,
+        '-api' => SWF::Builder->new(
             'FrameRate' => 15,
-            'FrameSize' => [
-                0,
-                0,
-                $opt{'-drawer'}->get_width,
-                $opt{'-drawer'}->get_height
-            ],
+            'FrameSize' =>
+              [ 0, 0, $opt{'-drawer'}->get_width, $opt{'-drawer'}->get_height ],
             'BackgroundColor' => 'ffffff'
         )
-    );    
+    );
     return bless $self, $class;
 }
 
@@ -64,7 +55,7 @@ sub _finish {
     $logger->debug("finishing drawing");
     my $self = shift;
     require File::Temp;
-    my ($fh, $filename) = File::Temp::tempfile();
+    my ( $fh, $filename ) = File::Temp::tempfile();
     $self->_api->save('file.swf');
 }
 
@@ -81,12 +72,9 @@ sub _draw_curve {
     my @keys = qw(-x1 -y1 -x2 -y2 -width -color);
     my ( $x1, $y1, $x3, $y3, $width, $color ) = @args{@keys};
     my ( $x2, $y2 ) = ( $x1, $y3 );
-    return $self->_api
-        ->new_shape
-        ->linestyle( $width || 1, $color || '000000' )
-        ->moveto($x1,$y1)
-        ->curveto($x1,$y1,$x1,$y1,$x2,$y2,$x3,$y3)
-        ->place;
+    return $self->_api->new_shape->linestyle( $width || 1, $color || '000000' )
+      ->moveto( $x1, $y1 )->curveto( $x1, $y1, $x1, $y1, $x2, $y2, $x3, $y3 )
+      ->place;
 }
 
 # required:
@@ -96,7 +84,6 @@ sub _draw_curve {
 # -y2 => $y2,
 # -x3 => $x3,
 # -y3 => $y3,
-
 # optional:
 # -fill   => $fill,
 # -stroke => $stroke,
@@ -108,15 +95,13 @@ sub _draw_triangle {
     $logger->debug("drawing triangle @_");
     my %args = @_;
     my @keys = qw(-x1 -y1 -x2 -y2 -x3 -y3 -fill -stroke -width -url -api);
-    my ( $x1,$y1,$x2,$y2,$x3,$y3,$fill,$stroke,$width,$url,$api) = @args{@keys};
-    return $self->_api->new_shape   # red triangle.
-        ->fillstyle( $fill  || 'ffffff' )
-        ->linestyle( $width || 1, $stroke || '000000' )
-        ->moveto(int $x1,int $y1)
-        ->lineto(int $x2,int $y2)
-        ->lineto(int $x3,int $y3)
-        ->lineto(int $x1,int $y1)
-        ->place;
+    my ( $x1, $y1, $x2, $y2, $x3, $y3, $fill, $stroke, $width, $url, $api ) =
+      @args{@keys};
+    return $self->_api->new_shape    # red triangle.
+      ->fillstyle( $fill || 'ffffff' )
+      ->linestyle( $width || 1, $stroke || '000000' )
+      ->moveto( int $x1, int $y1 )->lineto( int $x2, int $y2 )
+      ->lineto( int $x3, int $y3 )->lineto( int $x1, int $y1 )->place;
 }
 
 # -x1 => $x1,
@@ -131,12 +116,8 @@ sub _draw_line {
     my %args = @_;
     my @keys = qw(-x1 -y1 -x2 -y2 -width -color);
     my ( $x1, $y1, $x2, $y2, $width, $color ) = @args{@keys};
-    return $self->_api
-        ->new_shape
-        ->linestyle( $width || 1,$color || '000000' )
-        ->moveto($x1,$y1)        
-        ->lineto( $x1,$y1, $x2,$y2 )
-        ->place;
+    return $self->_api->new_shape->linestyle( $width || 1, $color || '000000' )
+      ->moveto( $x1, $y1 )->lineto( $x1, $y1, $x2, $y2 )->place;
 }
 
 # -x1 => $x1,
@@ -152,12 +133,8 @@ sub _draw_multi {
     my @keys = qw(-x1 -y1 -x2 -y2 -width -color);
     my ( $x1, $y1, $x3, $y3, $width, $color ) = @args{@keys};
     my ( $x2, $y2 ) = ( $x1, $y3 );
-    return $self->_api
-        ->new_shape
-        ->linestyle( $width || 1,$color || '000000' )
-        ->moveto($x1,$y1)        
-        ->lineto( $x1,$y1, $x2,$y2, $x3,$y3 )
-        ->place;
+    return $self->_api->new_shape->linestyle( $width || 1, $color || '000000' )
+      ->moveto( $x1, $y1 )->lineto( $x1, $y1, $x2, $y2, $x3, $y3 )->place;
 }
 
 # required:
@@ -171,22 +148,18 @@ sub _draw_text {
     $logger->debug("drawing text");
     my $self = shift;
     if ( not $self->{'FONT'} ) {
-        $self->{'FONT'} = $self
-            ->_api
-            ->new_font($Bio::Phylo::Treedrawer::Swf::FONT);
-    }    
+        $self->{'FONT'} =
+          $self->_api->new_font($Bio::Phylo::Treedrawer::Swf::FONT);
+    }
     my %args = @_;
     my ( $x, $y, $text, $url, $size ) = @args{qw(-x -y -text -url -size)};
-    if ( $url ) {
-        $text = sprintf('<a href="%s">%s</a>', $url, $text);
+    if ($url) {
+        $text = sprintf( '<a href="%s">%s</a>', $url, $text );
     }
-    my $textobj = $self
-        ->_api
-        ->new_html_text
-        ->font($self->{'FONT'})
-        ->size($size||12)
-        ->text($text);
-    return $textobj->place->moveto($x,$y);    
+    my $textobj =
+      $self->_api->new_html_text->font( $self->{'FONT'} )->size( $size || 12 )
+      ->text($text);
+    return $textobj->place->moveto( $x, $y );
 }
 
 # -x => $x,
@@ -203,13 +176,10 @@ sub _draw_circle {
     my %args = @_;
     my @keys = qw(-x -y -width -stroke -radius -fill -api -url);
     my ( $x, $y, $width, $stroke, $radius, $fill, $api, $url ) = @args{@keys};
-    my $circle = $self->_api
-        ->new_shape
-        ->fillstyle( $fill  || '000000' )
-        ->linestyle( $width || 1, $stroke || '000000' )
-        ->circle( $radius );        
-    return $circle->place->moveto( $x, $y );    
-    
+    my $circle =
+      $self->_api->new_shape->fillstyle( $fill || '000000' )
+      ->linestyle( $width || 1, $stroke || '000000' )->circle($radius);
+    return $circle->place->moveto( $x, $y );
 }
 
 =head1 SEE ALSO
@@ -238,8 +208,7 @@ L<http://dx.doi.org/10.1186/1471-2105-12-63>
 
 =head1 REVISION
 
- $Id: Swf.pm 1593 2011-02-27 15:26:04Z rvos $
+ $Id: Swf.pm 1660 2011-04-02 18:29:40Z rvos $
 
 =cut
-
 1;
